@@ -23,6 +23,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ############################################################################
 # adapted to maemo5/n900 by emme750
+# pyobd-0.9.2-22
 ############################################################################
 
 #import wxversion
@@ -76,6 +77,7 @@ ID_HELP_ORDER = 510
 ID_HELP_ABOUT_Maemo = 511
 ID_HELP_VISIT_Maemo = 512
 
+SX = 0
 
 # Define notification event for sensor result window
 EVT_RESULT_ID = 1000
@@ -155,7 +157,6 @@ class MyApp(wx.App):
             wx.ListCtrl.__init__(self,parent,id,pos,size,style)
             ListCtrlAutoWidthMixin.__init__(self)
 
-
                
     class sensorProducer(threading.Thread):
         def __init__(self, _notify_window,portName,SERTIMEOUT,RECONNATTEMPTS,_nb):
@@ -171,11 +172,6 @@ class MyApp(wx.App):
 
         def initCommunication(self):
 
-            #print self.portName
-            #print self._notify_window
-            #print self.SERTIMEOUT
-            #print self.RECONNATTEMPTS
-
             self.port = obd_io.OBDPort(self.portName,self._notify_window,self.SERTIMEOUT,self.RECONNATTEMPTS)
 
             if self.port.State==0: #Cant open serial port
@@ -211,6 +207,7 @@ class MyApp(wx.App):
             global btname, maxbar, maxmaf
             maxbar=0
             maxmaf=0
+            global SX
 
             wx.PostEvent(self._notify_window, StatusEvent([0,1,"Connecting...."]))
             try:
@@ -243,7 +240,7 @@ class MyApp(wx.App):
             curstate=-1
 
             while self._notify_window.ThreadControl!=666:
-                wx.Yield()
+                #wx.Yield()
                 prevstate=curstate
                 curstate=self._nb.GetSelection()
                 #print "curstate: "+str(curstate)
@@ -270,9 +267,12 @@ class MyApp(wx.App):
 
                       if self.active[i]:
                           s = self.port.sensor(i)
-                          wx.PostEvent(self._notify_window, ResultEvent([i,2,"%s (%s)" % (s[1], s[2])]))
+                          
+                          print s[1][0],s[1][1],s[2],s[3]
+                          wx.PostEvent(self._notify_window, ResultEvent([i,2,"%s (%s)" % (s[1][SX], s[2+SX])]))
 #log
-                          log1=str(s[0])+" : "+str(s[1])+" "+str(s[2])
+
+                          log1=str(s[0])+" : "+str(s[1][SX])+" "+str(s[2+SX])
                           #print s
                           print log1
                           log2="echo "+log1+" >> /home/user/MyDocs/pyobd.log"
@@ -336,54 +336,35 @@ class MyApp(wx.App):
 			speedsensor=13
 			if self.active[speedsensor]:
 				s = self.port.sensor(speedsensor)
-				text=str(s[1])
-				l=len(text)
-				n=0
-				while n<(l-1):
-					if str(text[n]) == '#' :
-						text="kmh"+text[0:n]
-						break
-					n=n+1
+				text=str(s[1][SX])
+				text="spe"+text
 				wx.PostEvent(self._notify_window, DialEvent(text))
+
 			speedsensor=12
 			if self.active[speedsensor]:
 				s = self.port.sensor(speedsensor)
-				text="rpm"+str(s[1])
+				text="rpm"+str(s[1][0])
 				wx.PostEvent(self._notify_window, DialEvent(text))
 			wx.Yield()
 
 		elif curstate==5:
 
-			speedsensor=11
-
+			speedsensor=11 # MAP
 			if self.active[speedsensor]:
 				s = self.port.sensor(speedsensor)
-				text=str(s[1])
-				l=len(text)
-				n=0
-				while n<(l-1):
-					if str(text[n]) == '#' :
-						text="MAP"+text[0:n]
-						break
-					n=n+1
+				text=str(s[1][0])
+				text="MAP"+text
+				print text
 				wx.PostEvent(self._notify_window, DialEvent1(text))
 
-				wx.Yield()                   
-
-			speedsensor=16
-
+			speedsensor=16 # MAF
 			if self.active[speedsensor]:
 				s = self.port.sensor(speedsensor)
-				text=str(s[1])
-				l=len(text)
-				n=0
-				while n<(l-1):
-					if str(text[n]) == '#' :
-						text="MAF"+text[0:n]
-						break
-					n=n+1
+				text=str(s[1][SX])
+				text="MAF"+text
+				print text
 				wx.PostEvent(self._notify_window, DialEvent1(text))
-				wx.Yield()                   
+			wx.Yield()                   
 
 
                 else:
@@ -703,8 +684,11 @@ class MyApp(wx.App):
         self.SpeedWindow3.SetMiddleTextFont(wx.Font(14, wx.SWISS, wx.NORMAL, wx.BOLD))
 
         self.SpeedWindow3.SetHandColour(wx.Colour(255, 255, 0))
-
-        self.SpeedWindow3.SetTitleText("MAP\n(intake manifold absolute pressure)\n\n\n\nMAF (Air Flow Rate) g/s#lb/s") #
+        if SX==0:
+             meas="g/s"
+        else:
+             meas="lb/s"
+        self.SpeedWindow3.SetTitleText("MAP\n(intake manifold absolute pressure)\n\n\n\nMAF (Air Flow Rate) "+meas) #
         self.SpeedWindow3.SetSubText("Max: -") #
         self.SpeedWindow3.SetSub2Text("Cur: -\nMax: -")
 
@@ -745,6 +729,7 @@ class MyApp(wx.App):
             self.trace.Append([str(level),msg])
         
     def OnInit(self):
+        global SX
         self.ThreadControl = 0 #say thread what to do
         self.COMPORT = 0
         self.senprod = None
@@ -791,10 +776,13 @@ class MyApp(wx.App):
         lungh = len(str(gauges_mph).strip())
         if lungh==(4):
            gauges_mph=True
+           SX=1
         else:
            gauges_mph=False
+           SX=0
 
         self.gauges_mph=gauges_mph
+
         #print self.gauges_mph
         if self.gauges_mph==True:
                 self.k=0.625
@@ -862,7 +850,7 @@ class MyApp(wx.App):
         self.filemenu= wx.Menu()
         self.filemenu.Append(ID_FULLSCREEN,"FullScreen ON/OFF","FullScreen")
         self.filemenu.AppendSeparator()
-        self.filemenu.Append(ID_GAUGES,"Configure Gauges","GAUGES")
+        self.filemenu.Append(ID_GAUGES,"Select Units of Measurements","GAUGES")
         self.filemenu.AppendSeparator()
         self.filemenu.Append(ID_EXIT,"Exit"," Terminate the program")
 
@@ -950,7 +938,7 @@ class MyApp(wx.App):
         stringa = 'dbus-send --print-reply --dest=com.nokia.osso_notes /com/nokia/osso_notes com.nokia.osso_notes.mime_open string:/home/opt/pyobd/pyobd.txt'
         os.popen(stringa)
 
-        Text = """ pyobd-0.9.2-21
+        Text = """ pyobd
 
 Adapted to n900 by m750 at maemo.org
 """
@@ -1021,15 +1009,13 @@ later version.
 
 
     def OnDial(self,event):
-	print "k: " + str(self.k)
 	wx.Yield()
 	data=event.data
+	print data
 	d1=data[:3]
 	d2=int(data[3:])
-	if d1=="kmh":
-		#print "speed: "+str(d2)
-		#print "k: " + str(self.k)
-		#print "speed: "+str(d2*self.k)
+	if d1=="spe":
+
 		if d2>200 and self.k==1:
 			d2=200
 			self.SpeedWindow1.SetTicksColour(wx.RED)
@@ -1040,7 +1026,7 @@ later version.
 		else:
 			self.SpeedWindow1.SetTicksColour(wx.WHITE)
 
-		self.SpeedWindow1.SetSpeedValue(d2*self.k)
+		self.SpeedWindow1.SetSpeedValue(d2)
 
 	elif d1=="rpm":
 		#print "rpm: "+str(d2)
@@ -1055,6 +1041,7 @@ later version.
 
     def OnDial1(self,event):
 	global maxbar, maxmaf
+	wx.Yield()
 	data=event.data
 
 	d1=data[:3]
@@ -1075,10 +1062,9 @@ later version.
 		d2=float(d2)
 		if d2>maxmaf:
 			maxmaf=d2
-		d2=str(d2)+"#"+str(d2*0.0022)[:6]
-		text="Cur: "+str(d2)+"\nMax: "+str(maxmaf)+"#"+str(maxmaf*0.0022)[:6]
+		d2=str(d2)                                 # +"#"+str(d2*0.0022)[:6]
+		text="Cur: "+str(d2)+"\nMax: "+str(maxmaf) # +"#"+str(maxmaf*0.0022)[:6]
 		self.SpeedWindow3.SetSub2Text(text)
-	wx.Yield()
 
 
     def OnDisconnect(self,event): #disconnect connection to ECU
@@ -1456,11 +1442,11 @@ later version.
 
     def On_gauge_mph_kmh(self,e = None):
         id=0
-        diag = wx.Dialog(self.frame, id, title="Configure Gauges")
+        diag = wx.Dialog(self.frame, id, title="Select Units of Measurements")
         sizer = wx.BoxSizer(wx.VERTICAL)
 
         mph_Panel = wx.Panel(diag, -1)
-        mph_Static = wx.CheckBox(mph_Panel,-1,' MPH instead KMH in the gauges\n   (To apply the changes, close and reopen pyOBD)',pos=(3,5),size=(700,100))
+        mph_Static = wx.CheckBox(mph_Panel,-1,' US/Imperial instead Metrical units\n   (To apply the changes, close and reopen pyOBD)',pos=(3,5),size=(700,100))
         mph_Static.SetValue(self.gauges_mph)
 
         sizer.Add(mph_Panel,0)
